Module format

Module format 

Formats for making the formatted outputs (see get_formatted_string)

Structs

FormattingOptions
Defines the parts which are used to print out the formatted string.

Statics

COMPATIBLE
A format made out of -’s and |’s. Very compatible with small charsets!
DEBUGGING
This format is for debugging the formatting functionality.
DOUBLED
This format is for those who like their lines doubled.
STREAMLINED
A very streamlined format. This is the default format.
STREAMLINED_ROUNDED
Like STREAMLINED except with rounded corners.