FormattingOptions

Struct FormattingOptions 

pub struct FormattingOptions {
    pub starting_branch: &'static str,
    pub continuing_branch: &'static str,
    pub branching_branch: &'static str,
    pub turning_branch: &'static str,
    pub ending_branch: &'static str,
    pub turning_ending_branch: &'static str,
}
Defines the parts which are used to print out the formatted string.

See the format module for options. You can make your own, if you can parse the sparse instructions below.

Reference print (see Fields)

>,,,, main                      - 100.0%, 300 ms/loop
  +,,,, physics simulation      -  66.7%, 200 ms/loop
  | +.... moving things         -  50.0%, 100 ms/loop
  | -.... resolving collisions  -  50.0%, 100 ms/loop
  -.... rendering               -  33.3%, 100 ms/loop

Fields

starting_branch: &'static str

See the reference-print, starting_branch is represented by “>”

continuing_branch: &'static str

See the reference-print, continuing_branch is represented by “|”

branching_branch: &'static str

See the reference-print, branching_branch is represented by “+”

turning_branch: &'static str

See the reference-print, turning_branch is represented by “-”

ending_branch: &'static str

See the reference-print, ending_branch is represented by “….”

turning_ending_branch: &'static str

See the reference-print, turning_ending_branch is represented by “,,,,”