Formats for making the formatted outputs (see
get_formatted_string)
Structs
- Formatting
Options - Defines the parts which are used to print out the formatted string.
Statics
- COMPATIBLE
- A format made out of -’s and |’s. Very compatible with small charsets!
- DEBUGGING
- This format is for debugging the formatting functionality.
- DOUBLED
- This format is for those who like their lines doubled.
- STREAMLINED
- A very streamlined format. This is the default format.
- STREAMLINED_
ROUNDED - Like
STREAMLINEDexcept with rounded corners.